import { ITextDocument } from './types/textDocument';
import { IUri } from './types/uri';
import { Disposable } from './util/dispose';
import { IMdWorkspace } from './workspace';
/**
 * Cache of information per-document in the workspace.
 *
 * The values are computed lazily and invalidated when the document changes.
 */
export declare class MdDocumentInfoCache<T> extends Disposable {
    private readonly workspace;
    private readonly getValue;
    private readonly _cache;
    private readonly _loadingDocuments;
    constructor(workspace: IMdWorkspace, getValue: (document: ITextDocument) => Promise<T>);
    get(resource: IUri): Promise<T | undefined>;
    getForDocument(document: ITextDocument): Promise<T>;
    private loadDocument;
    private resetEntry;
    private invalidate;
    private onDidDeleteDocument;
}
/**
 * Cache of information across all markdown files in the workspace.
 *
 * Unlike {@link MdDocumentInfoCache}, the entries here are computed eagerly for every file in the workspace.
 * However the computation of the values is still lazy.
 */
export declare class MdWorkspaceInfoCache<T> extends Disposable {
    private readonly workspace;
    private readonly getValue;
    private readonly _cache;
    private _init?;
    constructor(workspace: IMdWorkspace, getValue: (document: ITextDocument) => Promise<T>);
    entries(): Promise<Array<[IUri, T]>>;
    values(): Promise<Array<T>>;
    getForDocs(docs: readonly ITextDocument[]): Promise<T[]>;
    private ensureInit;
    private populateCache;
    private update;
    private onDidChangeDocument;
    private onDidDeleteDocument;
}
